==> bw-xml-synchws-4.0.8-sources.jar: ietf/params/xml/ns/icalendar_2/TextPropertyType.java <==

package ietf.params.xml.ns.icalendar_2;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TextPropertyType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TextPropertyType">
 *   &lt;complexContent>
 *     &lt;extension base="{urn:ietf:params:xml:ns:icalendar-2.0}BasePropertyType">
 *       &lt;sequence>
 *         &lt;element ref="{urn:ietf:params:xml:ns:icalendar-2.0}text"/>
 *       &lt;/sequence>
 *     &lt;/extension>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TextPropertyType", propOrder = {
    "text"
})
@XmlSeeAlso({
    ActionPropType.class,
    TzidPropType.class,
    MethodPropType.class,
    XBedeworkWrapperPropType.class,
    ProdidPropType.class,
    VersionPropType.class,
    StatusPropType.class,
    XBedeworkInstanceOnlyPropType.class,
    XBwLocationPropType.class,
    XMicrosoftCdoBusystatusPropType.class,
    XBwContactPropType.class,
    UidPropType.class,
    XBedeworkExsynchLastmodPropType.class,
    XBedeworkExsynchStarttzidPropType.class,
    PollModePropType.class,
    PollPropertiesPropType.class,
    XBedeworkCostPropType.class,
    XBedeworkExsynchEndtzidPropType.class,
    ContactPropType.class,
    XBedeworkWaitListLimitPropType.class,
    WsCalendarTypeType.class,
    TranspPropType.class,
    XMicrosoftCdoIntendedstatusPropType.class,
    DescriptionPropType.class,
    TznamePropType.class,
    AcceptResponsePropType.class,
    ClassPropType.class,
    SummaryPropType.class,
    CommentPropType.class,
    LocationPropType.class,
    BusytypePropType.class
})
public class TextPropertyType
    extends BasePropertyType
{

    @XmlElement(required = true)
    protected String text;

    /**
     * Gets the value of the text property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getText() {
        return text;
    }

    /**
     * Sets the value of the text property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setText(String value) {
        this.text = value;
    }

}

==> bw-xml-synchws-4.0.11-sources.jar: ietf/params/xml/ns/icalendar_2/TextPropertyType.java <==

package ietf.params.xml.ns.icalendar_2;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSeeAlso;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for TextPropertyType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="TextPropertyType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{urn:ietf:params:xml:ns:icalendar-2.0}BasePropertyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{urn:ietf:params:xml:ns:icalendar-2.0}text"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "TextPropertyType", propOrder = {
    "text"
})
@XmlSeeAlso({
    MethodPropType.class,
    ProdidPropType.class,
    VersionPropType.class,
    ClassPropType.class,
    CommentPropType.class,
    DescriptionPropType.class,
    LocationPropType.class,
    StatusPropType.class,
    SummaryPropType.class,
    TranspPropType.class,
    TzidPropType.class,
    TznamePropType.class,
    ContactPropType.class,
    UidPropType.class,
    ActionPropType.class,
    AcceptResponsePropType.class,
    PollModePropType.class,
    PollPropertiesPropType.class,
    XBedeworkCostPropType.class,
    XBedeworkExsynchEndtzidPropType.class,
    XBedeworkExsynchLastmodPropType.class,
    XBedeworkExsynchStarttzidPropType.class,
    XBwLocationPropType.class,
    XBwContactPropType.class,
    XBedeworkInstanceOnlyPropType.class,
    XBedeworkWaitListLimitPropType.class,
    XBedeworkWrapperPropType.class,
    XMicrosoftCdoBusystatusPropType.class,
    XMicrosoftCdoIntendedstatusPropType.class,
    WsCalendarTypeType.class,
    BusytypePropType.class
})
public class TextPropertyType
    extends BasePropertyType
{

    @XmlElement(required = true)
    protected String text;

    /**
     * Gets the value of the text property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getText() {
        return text;
    }

    /**
     * Sets the value of the text property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setText(String value) {
        this.text = value;
    }

}
